==> haskell-tasty-expected-failure-0.12.3-210-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-expected-failure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-expected-failure
version:              0.12.3
visibility:           public
id:                   tasty-expected-failure-0.12.3-A3vnjZRFjucBwfONLkOEAW
key:                  tasty-expected-failure-0.12.3-A3vnjZRFjucBwfONLkOEAW
license:              MIT
copyright:            2015 Joachim Breitner
maintainer:           mail@joachim-breitner.de
author:               Joachim Breitner
homepage:             http://github.com/nomeata/tasty-expected-failure
synopsis:             Mark tasty tests as failure expected
description:
    With the function '\''Test.Tasty.ExpectedFailure.expectFail'\'' in the provided module
    "Test.Tasty.ExpectedFailure", you can mark that you expect test cases to fail,
    and not to pass.

    This can for example be used for test-driven development: Create the tests,
    mark them with '\''Test.Tasty.ExpectedFailure.expectFail'\'', and you can still push
    to the main branch, without your continuous integration branch failing.

    Once someone implements the feature or fixes the bug (maybe unknowingly), the
    test suite will tell him so, due to the now unexpectedly passing test, and he
    can remove the '\''Test.Tasty.ExpectedFailure.expectFail'\'' marker.

    The module also provides '\''Test.Tasty.ExpectedFailure.ignoreTest'\'' to avoid
    running a test. Both funtions are implemented via the more general
    '\''Test.Tasty.ExpectedFailure.wrapTest'\'', which is also provided.

category:             Testing
abi:                  69bfc4bd5f262943b20fea2f9901e2a7
exposed:              True
exposed-modules:      Test.Tasty.ExpectedFailure
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-expected-failure-0.12.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-expected-failure-0.12.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-expected-failure
hs-libraries:         HStasty-expected-failure-0.12.3-A3vnjZRFjucBwfONLkOEAW
depends:
    base-4.15.1.0 tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR
    tasty-1.4.2.2-AfkvjgAgyIO8Wpi2IVD0lg
    unbounded-delays-0.1.1.1-KU4Jg1KyC6i76f9JqBmZ6Z

haddock-interfaces:
    /usr/share/doc/haskell-tasty-expected-failure/html/tasty-expected-failure.haddock

haddock-html:         /usr/share/doc/haskell-tasty-expected-failure/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-expected-failure-0.12.3-218-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-expected-failure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-expected-failure
version:              0.12.3
visibility:           public
id:                   tasty-expected-failure-0.12.3-6DHbUz8p5k9HWju0HjZEUD
key:                  tasty-expected-failure-0.12.3-6DHbUz8p5k9HWju0HjZEUD
license:              MIT
copyright:            2015 Joachim Breitner
maintainer:           mail@joachim-breitner.de
author:               Joachim Breitner
homepage:             http://github.com/nomeata/tasty-expected-failure
synopsis:             Mark tasty tests as failure expected
description:
    With the function '\''Test.Tasty.ExpectedFailure.expectFail'\'' in the provided module
    "Test.Tasty.ExpectedFailure", you can mark that you expect test cases to fail,
    and not to pass.

    This can for example be used for test-driven development: Create the tests,
    mark them with '\''Test.Tasty.ExpectedFailure.expectFail'\'', and you can still push
    to the main branch, without your continuous integration branch failing.

    Once someone implements the feature or fixes the bug (maybe unknowingly), the
    test suite will tell him so, due to the now unexpectedly passing test, and he
    can remove the '\''Test.Tasty.ExpectedFailure.expectFail'\'' marker.

    The module also provides '\''Test.Tasty.ExpectedFailure.ignoreTest'\'' to avoid
    running a test. Both funtions are implemented via the more general
    '\''Test.Tasty.ExpectedFailure.wrapTest'\'', which is also provided.

category:             Testing
abi:                  c8b224a8cd8aea506e2aa97d0c1069d8
exposed:              True
exposed-modules:      Test.Tasty.ExpectedFailure
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-expected-failure-0.12.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-expected-failure-0.12.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-expected-failure
hs-libraries:         HStasty-expected-failure-0.12.3-6DHbUz8p5k9HWju0HjZEUD
depends:
    base-4.15.1.0 tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR
    tasty-1.4.2.3-5Q3D4h6lqeE1Hc7cRlyl02
    unbounded-delays-0.1.1.1-KU4Jg1KyC6i76f9JqBmZ6Z

haddock-interfaces:
    /usr/share/doc/haskell-tasty-expected-failure/html/tasty-expected-failure.haddock

haddock-html:         /usr/share/doc/haskell-tasty-expected-failure/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
